X-Git-Url: https://git.rapsys.eu/userbundle/blobdiff_plain/c10ada0bebaf63162b0db1866f643984bdadbb30..038e583ee27e5e1fe587c4798d5dcc7d831be5a8:/Entity/Group.php?ds=inline

diff --git a/Entity/Group.php b/Entity/Group.php
index d7ca3c7..c97515c 100644
--- a/Entity/Group.php
+++ b/Entity/Group.php
@@ -1,7 +1,7 @@
 <?php declare(strict_types=1);
 
 /*
  * This file is part of the Rapsys PackBundle package.
  *
  * (c) Raphaël Gertz <symfony@rapsys.eu>
  *
@@ -12,6 +12,7 @@
 namespace Rapsys\UserBundle\Entity;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\ORM\Event\PreUpdateEventArgs;
 
 use Rapsys\UserBundle\Entity\User;
 
@@ -50,7 +51,10 @@ class Group {
 	 * @param string $title The group name
 	 */
 	public function __construct(string $title) {
+		//Set defaults
 		$this->title = $title;
+		$this->created = new \DateTime('now');
+		$this->updated = new \DateTime('now');
 		$this->users = new ArrayCollection();
 	}
 
@@ -160,6 +164,17 @@ class Group {
 		return $this->users;
 	}
 
+	/**
+	 * {@inheritdoc}
+	 */
+	public function preUpdate(PreUpdateEventArgs $eventArgs) {
+		//Check that we have a group instance
+		if (($user = $eventArgs->getEntity()) instanceof Group) {
+			//Set updated value
+			$user->setUpdated(new \DateTime('now'));
+		}
+	}
+
 	/**
 	 * Returns a string representation of the group
 	 *
@@ -1,7 +1,7 @@
 
 /*
- * This file is part of the Rapsys PackBundle package.
+ * This file is part of the Rapsys UserBundle package.
  *
  * (c) Raphaël Gertz <symfony@rapsys.eu>